***************************************************************************
:mod:`mopidy.mixers.gstreamer_software` -- Software mixer for all platforms
***************************************************************************

.. inheritance-diagram:: mopidy.mixers.gstreamer_software

.. automodule:: mopidy.mixers.gstreamer_software
    :synopsis: Software mixer for all platforms
    :members:
